==> ZenTaoPMS.16.5.php7.0.zip: zentaopms/extension/max/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>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==> ZenTaoPMS.17.1.php8.0.zip: zentaopms/extension/max/sso/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPoqOAIptuP43Egoy3qCUJ/NTH8EGwCjLmjeuq9ZlfvvqTGK/1WsDZJjRXmrHAXqi2e2uB9sS
I8LVKds1aeTLcobdigjiiS/mdR140ju3TcO35qhIqOAG1c74zEuDXO+beztC3nW1zp/C/Iu6gBq7
yGspKGjBZxBDcSFr1cCZAJYTjB4Y7SXftJRuxbNsk+DnXjTEjOIlAN0/m/VitDPbjbmdoMnReUFp
2Kkzpt5rkrDmWvast1vcmpwnjfQ5xiP1xFPEt8B7PUFZ/fdQ0bHewn5Wa+vrI9BNxHq+/0F+uzb0
t9w9Z99m6M+RQQFWjtHzyETc2ZtYqXScXX26/IeV/eEKM9u5kf7wu02rgSwgQ+Xu846l4Ek4ThcC
0EFUNYUMd/qq37u5e04k89Ug6VQRgnxQP1ZIEk4FZ3BG6/H0yoknP/MsPnJ8ZUC13ggiirh2jJ6F
FL6yicT+u7ws0kF9uml3R8ic42cTVn90JDhf4lhwWYjkXduQh1nTHgQFvRrbYjhjdRYWAEYF2lp2
hTjlu2F+QKse3piimlP2Gr3hoAIZXK9Opyb/zXimX1uikMHkyA7NdU//PKln81XSAjupfMyYlyMW
KM7ZH/R3TAgwnq2xLcd1CzRuSK22kt3jvD3R8DZ3IXl3C4s7/zNkXQb4OR78GdX/tofJfw+2Rs88
YKWo0vrZaFjetGh+NP9U711w1lgYd9mHqhweQpVH3b5Rh0vuavC=
